Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(419)

Unified Diff: ui/views/window/dialog_client_view.h

Issue 12225095: Interactive autofill: Adds footnote view to accept legal documents in the UI. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: . Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/views/window/dialog_client_view.h
diff --git a/ui/views/window/dialog_client_view.h b/ui/views/window/dialog_client_view.h
index c8136d40267acd2b15efac423d30afe8dc6d765d..e5cd49df8fd2137dd5a94173ab68499aef8791c4 100644
--- a/ui/views/window/dialog_client_view.h
+++ b/ui/views/window/dialog_client_view.h
@@ -119,9 +119,9 @@ class VIEWS_EXPORT DialogClientView : public ClientView,
// and the spacing between bottom of buttons to end of the dialog.
int GetDialogButtonsAreaHeight() const;
- // Returns the preferred height of |footnote_view_|, or 0 if that view is
- // NULL.
- int GetFootnoteViewHeight() const;
+ // Returns the size of |footnote_view_|. If |footnote_view_| is NULL or
+ // !visible(), gfx::Size() will be returned.
+ gfx::Size GetFootnoteSize() const;
// Position and size various sub-views.
void LayoutDialogButtons();

Powered by Google App Engine
This is Rietveld 408576698